@@ -9,7 +9,7 @@ from datetime import timedelta
 from math import ceil, floor
 from typing import Dict, List, Optional
 
-from requests import post as requests_post
+import requests
 from yellowdog_client.model import (
     AllNodesInactiveShutdownCondition,
     AllWorkersReleasedShutdownCondition,
@@ -32,7 +32,12 @@ from yd_commands.mustache import (
     load_json_file_with_mustache_substitutions,
     load_jsonnet_file_with_mustache_substitutions,
 )
-from yd_commands.printing import print_error, print_log
+from yd_commands.printing import (
+    print_error,
+    print_log,
+    print_worker_pool,
+    print_yd_object,
+)
 from yd_commands.wrapper import CLIENT, CONFIG_COMMON, main_wrapper
 
 
@@ -85,15 +90,27 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
         reqt_template_usage: Dict = wp_data["requirementTemplateUsage"]
         for key, value in [
             # Generate a default name
-            ("requirementName", generate_id("wp" + "_" + CONFIG_COMMON.name_tag)),
+            (
+                "requirementName",
+                CONFIG_WP.name
+                if CONFIG_WP.name is not None
+                else generate_id("wp" + "_" + CONFIG_COMMON.name_tag),
+            ),
             ("requirementNamespace", CONFIG_COMMON.namespace),
             ("requirementTag", CONFIG_COMMON.name_tag),
             ("templateId", CONFIG_WP.template_id),
+            ("userData", CONFIG_WP.user_data),
+            ("imagesId", CONFIG_WP.images_id),
+            ("instanceTags", CONFIG_WP.instance_tags),
+            ("targetInstanceCount", CONFIG_WP.target_instance_count),
         ]:
-            if reqt_template_usage.get(key) is None:
+            if reqt_template_usage.get(key) is None and value is not None:
                 print_log(f"Setting 'requirementTemplateUsage.{key}': '{value}'")
                 reqt_template_usage[key] = value
-        if wp_data["provisionedProperties"].get("workerTag") is None:
+        if (
+            wp_data["provisionedProperties"].get("workerTag") is None
+            and CONFIG_WP.worker_tag is not None
+        ):
             print_log(
                 f"Setting 'provisionedProperties.workerTag': '{CONFIG_WP.worker_tag}'"
             )
@@ -101,12 +118,17 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
     except KeyError as e:
         raise Exception(f"Missing key error in JSON Worker Pool definition: {e}")
 
-    response = requests_post(
+    if ARGS_PARSER.dry_run:
+        print_log("Dry-run: Printing JSON Worker Pool specification")
+        print_yd_object(wp_data)
+        print_log("Dry run: Complete")
+        return
+
+    response = requests.post(
         url=f"{CONFIG_COMMON.url}/workerPools/provisioned/template",
         headers={"Authorization": f"yd-key {CONFIG_COMMON.key}:{CONFIG_COMMON.secret}"},
         json=wp_data,
     )
-
     name = wp_data["requirementTemplateUsage"]["requirementName"]
     if response.status_code == 200:
         print_log(f"Provisioned Worker Pool '{name}'")
@@ -121,7 +143,7 @@ def create_worker_pool():
     """
     # Check for well-configured node quantities
     if not (
-        CONFIG_WP.min_nodes <= CONFIG_WP.initial_nodes <= CONFIG_WP.max_nodes
+        CONFIG_WP.min_nodes <= CONFIG_WP.target_instance_count <= CONFIG_WP.max_nodes
         and CONFIG_WP.max_nodes > 0
     ):
         print_error(
@@ -161,7 +183,7 @@ def create_worker_pool():
 
     # Create the Worker Pool
     print_log(
-        f"Provisioning {CONFIG_WP.initial_nodes:,d} node(s) "
+        f"Provisioning {CONFIG_WP.target_instance_count:,d} node(s) "
         f"with {node_workers.targetCount:,d} worker(s) per "
         f"{node_workers.targetType} "
         f"(minNodes: {CONFIG_WP.min_nodes:,d}, "
@@ -169,7 +191,7 @@ def create_worker_pool():
     )
     batches: List[WPBatch] = _allocate_nodes_to_batches(
         CONFIG_WP.compute_requirement_batch_size,
-        CONFIG_WP.initial_nodes,
+        CONFIG_WP.target_instance_count,
         CONFIG_WP.min_nodes,
         CONFIG_WP.max_nodes,
     )
@@ -182,7 +204,7 @@ def create_worker_pool():
         )
         if num_batches > 1:
             print_log(
-                f"Provisioning Worker Pool {batch_number + 1} '{id}'"
+                f"Provisioning Worker Pool {batch_number + 1} '{id}' "
                 f"with {batches[batch_number].initial_nodes:,d} nodes(s) "
                 f"(minNodes: {batches[batch_number].min_nodes:,d}, "
                 f"maxNodes: {batches[batch_number].max_nodes:,d})"
@@ -190,27 +212,40 @@ def create_worker_pool():
         else:
             print_log(f"Provisioning Worker Pool '{id}'")
         try:
-            worker_pool = CLIENT.worker_pool_client.provision_worker_pool(
-                ComputeRequirementTemplateUsage(
-                    templateId=CONFIG_WP.template_id,
-                    requirementNamespace=CONFIG_COMMON.namespace,
-                    requirementName=id,
-                    targetInstanceCount=batches[batch_number].initial_nodes,
-                    requirementTag=CONFIG_COMMON.name_tag,
-                ),
-                ProvisionedWorkerPoolProperties(
-                    createNodeWorkers=node_workers,
-                    minNodes=batches[batch_number].min_nodes,
-                    maxNodes=batches[batch_number].max_nodes,
-                    workerTag=CONFIG_WP.worker_tag,
-                    autoShutdown=CONFIG_WP.auto_shutdown,
-                    autoShutdownConditions=auto_shutdown_conditions,
-                    nodeIdleTimeLimit=auto_scaling_idle_delay,
-                    nodeIdleGracePeriod=auto_scaling_idle_delay,
-                    nodeBootTimeLimit=node_boot_time_limit,
-                ),
+            compute_requirement_template_usage = ComputeRequirementTemplateUsage(
+                templateId=CONFIG_WP.template_id,
+                requirementNamespace=CONFIG_COMMON.namespace,
+                requirementName=id,
+                targetInstanceCount=batches[batch_number].initial_nodes,
+                requirementTag=CONFIG_COMMON.name_tag,
+                userData=CONFIG_WP.user_data,
+                imagesId=CONFIG_WP.images_id,
+                instanceTags=CONFIG_WP.instance_tags,
             )
-            print_log(f"Created {link_entity(CONFIG_COMMON.url, worker_pool)}")
+            provisioned_worker_pool_properties = ProvisionedWorkerPoolProperties(
+                createNodeWorkers=node_workers,
+                minNodes=batches[batch_number].min_nodes,
+                maxNodes=batches[batch_number].max_nodes,
+                workerTag=CONFIG_WP.worker_tag,
+                autoShutdown=CONFIG_WP.auto_shutdown,
+                autoShutdownConditions=auto_shutdown_conditions,
+                nodeIdleTimeLimit=auto_scaling_idle_delay,
+                nodeIdleGracePeriod=auto_scaling_idle_delay,
+                nodeBootTimeLimit=node_boot_time_limit,
+            )
+            if not ARGS_PARSER.dry_run:
+                worker_pool = CLIENT.worker_pool_client.provision_worker_pool(
+                    compute_requirement_template_usage,
+                    provisioned_worker_pool_properties,
+                )
+                print_log(f"Created {link_entity(CONFIG_COMMON.url, worker_pool)}")
+            else:
+                print_worker_pool(
+                    compute_requirement_template_usage,
+                    provisioned_worker_pool_properties,
+                )
+                return
+
         except Exception as e:
             print_error(f"Unable to provision worker pool")
             raise Exception(e)
